#!/usr/bin/perl -w -I ../../lib

use 5.018;

use strict;

use Carp;

{ package Narwhal::Synth;
    use Moose;
    use Moose::Util::TypeConstraints;
      
    has 'length' => (
        is => 'rw',
        isa => 'Num',
    );
}

1;