#!/usr/bin/perl -w -I ../../lib

use 5.018;

use strict;

use Carp;

{ package Narwhal::Effect;
  
  use Moose;
  use Moose::Util::TypeConstraints;
  
  enum 'FX', [qw(fade)];

  has 'fx' => (
    is => 'rw',
    isa => 'FX',
  );

  sub BUILD {
    my $self = shift;
    # set default synthesizer
    my @classparts = split(/::/,ref($self));
    $self->fx(lc($classparts[-1]));
  }
  
  sub soxi {
    return("");
  }
}

1;